#!/usr/bin/python
#-*-coding:utf-8-*-
"""
    Script d'activation d'action ead
    (crée un lien symbolique de l'action vers le répertoire cible)
"""
import getopt, sys
from os import system
from os.path import join, isfile, isdir

sys.path.append('/usr/share')

from ead2.backend.config.config import ENABLED_ACTION_DIR
DOC = """
Usage : active_action.py [PYFILEPATH]
Active l'importation d'un fichier d'action par l'ead.
Crée un lien entre pointant vers pyfilepath depuis /etc/ead/sites-enabled/.
Ce fichier sera alors chargé automatiquement au redémarrage du service ead-server.

Ex :
1) active_action.py /root/monaction.py
Crée un lien symbolique de /etc/ead/sites-enabled/monaction.py vers /root/monaction.py

NB:
Les templates des actions doivent être placés dans /usr/share/ead2/backend/template.
Les css peuvent être placées directement dans le frontend dans :
/usr/share/ead2/frontend/web/static/style/
"""

def usage():
    """
        print la doc
    """
    print DOC

def main():
    """
        lance la commande
    """
    try:
        opts, args = getopt.getopt(sys.argv[1:], "h", ["help"])
    except getopt.GetoptError, err:
        print str(err)
        usage()
        sys.exit(2)
    for option, value in opts:
        if option in ('-h', '--help'):
            usage()
            sys.exit(0)
    try:
        target = args[0]
    except IndexError:
        print("-- THE PATH TO THE ACTION FILE IS MISSING --")
        usage()
        sys.exit(2)
    actionfilename = target.split()[1]
    linkname = join(ENABLED_ACTION_DIR, actionfilename)
    if not isfile(target):
        print("-- WRONG PATH : THE ACTION FILE \"%s\" DOESN'T EXIST --" % (
                                                              target,))
        usage()
        sys.exit(2)
    if isfile(linkname):
        print("Un fichier d'action du même nom existe déjà (\"%s\"), \
renommez votre fichier." % (linkname,))
        usage()
        sys.exit(2)

    # on crée le répertoire si il n'existe pas
    if not isdir(ENABLED_ACTION_DIR):
        if system("/bin/mkdir -p %s" % (ENABLED_ACTION_DIR,)) != 0:
            print("Une erreur est survenue à la création du répertoire \"%s\"" % (
                                                              ENABLED_ACTION_DIR,))
            usage()
            exit(2)
    # on crée le lien symbolique
    exit(system("/bin/ln -s '%s' '%s'" % (target, linkname)) )

if __name__ == '__main__':
    main()
